const config = require('config')

// const staffEmail = config.get('journal.staffEmail')
const journalName = config.get('journal.name')

const getEmailCopy = ({ emailType, titleText, comments }) => {
  let paragraph
  let hasLink = true
  let hasIntro = true
  let hasSignature = true
  switch (emailType) {
    case 'eqs-manuscript-accepted':
      hasIntro = false
      hasSignature = false
      paragraph = `A new ${titleText} has been submitted to ${journalName}.<br/><br/>
        To begin the review process, please visit the manuscript details page.`
      break
    case 'he-manuscript-published':
      hasLink = false
      paragraph = `Thank you for your recommendation to publish ${titleText} based on the reviews you received.<br/><br/>
      I can confirm this article will now go through to publication.`
      break
    case 'author-manuscript-published':
      paragraph = `I am delighted to inform you that ${titleText} has passed through the review process and will be published in Hindawi.<br/><br/>
        Thanks again for choosing to publish with us.`
      hasLink = false
      break
    case 'submitted-reviewers-after-publish':
      hasLink = false
      paragraph = `Thank you for your review on ${titleText}. After taking into account the reviews and the recommendation of the Handling Editor, I can confirm this article will now be published.<br/><br/>
      If you have any queries about this decision, then please email them to Hindawi as soon as possible.`
      break
    case 'eqa-manuscript-returned-to-eic':
      paragraph = `We regret to inform you that ${titleText} has been returned with comments. Please click the link below to access the manuscript.<br/><br/>
        Comments: ${comments}<br/><br/>`
      break
    default:
      throw new Error(`The ${emailType} email type is not defined.`)
  }

  return { paragraph, hasLink, hasIntro, hasSignature }
}

module.exports = {
  getEmailCopy,
}
